@@ -3,7 +3,7 @@ from rest_framework import routers
 
 from notification_system.api.views import (NotificationEventViewSet, EmailTemplateViewSet, OutgoingMessageViewSet,
                                            OutgoingMessageNotificationAPIView, NotificationGroupViewSet,
-                                           SmtpProviderViewSet)
+                                           SmtpProviderViewSet, MedialViewSet)
 
 app_name = "notification_events"
 
@@ -13,6 +13,7 @@ router.register("email-templates", EmailTemplateViewSet, basename="email_templat
 router.register("outgoing-messages", OutgoingMessageViewSet, basename="outgoing_messages")
 router.register("notification-groups", NotificationGroupViewSet, basename="notification_groups")
 router.register("smtp-providers", SmtpProviderViewSet, basename="smtp_providers")
+router.register("media", MedialViewSet, basename="media")
 
 urlpatterns = router.urls
 
