@@ -37,7 +37,7 @@ class NotificationEventViewSet(mixins.ListModelMixin,
     pagination_class = CustomLimitOffsetPagination
     filter_backends = [DjangoFilterBackend, filters.OrderingFilter]
     ordering_fields = ['id']
-    filter_fields = ['notification_groups', 'recipients']
+    filter_fields = ['notification_groups', 'recipients', 'notification_event_type']
 
     def get_queryset(self):
         queryset = super().get_queryset()
